@@ -33,12 +33,12 @@
 #include <tqradiobutton.h>
 #include <tqtextcodec.h>
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kcombobox.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <kcharsets.h>
 
 CSVDialog::CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString /*seperator*/)
@@ -62,7 +62,7 @@ CSVDialog::CSVDialog(TQWidget* parent, TQByteArray& fileArray, const TQString /*
     TQStringList encodings;
     encodings << i18n( "Descriptive encoding name", "Recommended ( %1 )" ).arg( "UTF-8" );
     encodings << i18n( "Descriptive encoding name", "Locale ( %1 )" ).arg( TQTextCodec::codecForLocale()->name() );
-    encodings += KGlobal::charsets()->descriptiveEncodingNames();
+    encodings += TDEGlobal::charsets()->descriptiveEncodingNames();
     // Add a few non-standard encodings, which might be useful for text files
     const TQString description(i18n("Descriptive encoding name","Other ( %1 )"));
     encodings << description.arg("Apple Roman"); // Apple
@@ -118,7 +118,7 @@ CSVDialog::~CSVDialog()
 
 void CSVDialog::loadSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("CSVDialog Settings");
     m_textquote = config->readEntry("textquote", "\"")[0];
     m_delimiter = config->readEntry("delimiter", ",");
@@ -145,7 +145,7 @@ void CSVDialog::loadSettings()
 
 void CSVDialog::saveSettings()
 {
-    KConfig *config = kapp->config();
+    TDEConfig *config = kapp->config();
     config->setGroup("CSVDialog Settings");
     TQString q = m_textquote;
     config->writeEntry("textquote", q);
@@ -591,7 +591,7 @@ void CSVDialog::ignoreDuplicatesChanged(int)
 
 TQTextCodec* CSVDialog::getCodec(void) const
 {
-    const TQString strCodec( KGlobal::charsets()->encodingForName( m_dialog->comboBoxEncoding->currentText() ) );
+    const TQString strCodec( TDEGlobal::charsets()->encodingForName( m_dialog->comboBoxEncoding->currentText() ) );
     kdDebug(30502) << "Encoding: " << strCodec << endl;
 
     bool ok = false;
@@ -604,7 +604,7 @@ TQTextCodec* CSVDialog::getCodec(void) const
     }
     else
     {
-        codec = KGlobal::charsets()->codecForName( strCodec, ok );
+        codec = TDEGlobal::charsets()->codecForName( strCodec, ok );
     }
 
     // Still nothing?
