@@ -20,13 +20,13 @@
 #include "kchartBackgroundPixmapConfigPage.h"
 #include "kchartBackgroundPixmapConfigPage.moc"
 
-#include <klocale.h>
-#include <kglobal.h>
+#include <tdelocale.h>
+#include <tdeglobal.h>
 #include <kstandarddirs.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+#include <tdefiledialog.h>
+#include <tdemessagebox.h>
 #include <kdebug.h>
-#include <kfilemetainfo.h>
+#include <tdefilemetainfo.h>
 #include <kstringhandler.h>
 
 #include <tqcombobox.h>
@@ -87,7 +87,7 @@ KChartBackgroundPixmapConfigPage::KChartBackgroundPixmapConfigPage( KChartParams
     wallCB = new TQComboBox( false, this, "wallCombo" );
     wallpaperLA->setBuddy(wallCB);
     TQWhatsThis::add( wallCB, i18n( "You can select a background image from "
-                                   "this list. Initially, the installed KDE "
+                                   "this list. Initially, the installed TDE "
                                    "wallpapers will be offered. If you do not "
                                    "find what you are looking for here, you can "
                                    "select any image file by clicking on the "
@@ -181,7 +181,7 @@ void KChartBackgroundPixmapConfigPage::loadWallpaperFilesList()
    TQMap<TQString, TQPair<TQString, TQString> > papers;
 
    //search for .desktop files before searching for images without .desktop files
-   TQStringList lst =  KGlobal::dirs()->findAllResources("wallpaper", "*desktop", false, true);
+   TQStringList lst =  TDEGlobal::dirs()->findAllResources("wallpaper", "*desktop", false, true);
    TQStringList files;
    for (TQStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it)
    {
@@ -219,7 +219,7 @@ void KChartBackgroundPixmapConfigPage::loadWallpaperFilesList()
    }
 
    //now find any wallpapers that don't have a .desktop file
-   lst =  KGlobal::dirs()->findAllResources("wallpaper", "*", false, true);
+   lst =  TDEGlobal::dirs()->findAllResources("wallpaper", "*", false, true);
    for (TQStringList::ConstIterator it = lst.begin(); it != lst.end(); ++it)
    {
       if ( !(*it).endsWith(".desktop") && files.grep(*it).empty() ) {
