@@ -37,12 +37,12 @@
 #include <tqlabel.h>
 #include <tqwhatsthis.h>
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdelocale.h>
 #include <kdebug.h>
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 
 #ifndef KEXI_NO_PRINT
 # include <kprinter.h>
@@ -60,7 +60,7 @@
 #include <kexidb/cursor.h>
 
 KexiTableView::Appearance::Appearance(TQWidget *widget)
- : alternateBackgroundColor( KGlobalSettings::alternateBackgroundColor() )
+ : alternateBackgroundColor( TDEGlobalSettings::alternateBackgroundColor() )
 {
 	//set defaults
 	if (tqApp) {
@@ -185,7 +185,7 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
 	d = new KexiTableViewPrivate(this);
 
 	connect( kapp, TQT_SIGNAL( settingsChanged(int) ), TQT_SLOT( slotSettingsChanged(int) ) );
-	slotSettingsChanged(KApplication::SETTINGS_SHORTCUTS);
+	slotSettingsChanged(TDEApplication::SETTINGS_SHORTCUTS);
 
 	m_data = new KexiTableViewData(); //to prevent crash because m_data==0
 	m_owner = true;                   //-this will be deleted if needed
@@ -207,7 +207,7 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
 //	d->baseColor = colorGroup().base();
 //	d->textColor = colorGroup().text();
 
-//	d->altColor = KGlobalSettings::alternateBackgroundColor();
+//	d->altColor = TDEGlobalSettings::alternateBackgroundColor();
 //	d->grayColor = TQColor(200,200,200);
 	d->diagonalGrayPattern = TQBrush(d->appearance.borderColor, TQt::BDiagPattern);
 
@@ -217,11 +217,11 @@ KexiTableView::KexiTableView(KexiTableViewData* data, TQWidget* parent, const ch
 	verticalScrollBar()->raise();
 
 	//context menu
-	m_popupMenu = new KPopupMenu(this, "contextMenu");
+	m_popupMenu = new TDEPopupMenu(this, "contextMenu");
 #if 0 //moved to mainwindow's actions
 	d->menu_id_addRecord = m_popupMenu->insertItem(i18n("Add Record"), this, TQT_SLOT(addRecord()), TQt::CTRL+TQt::Key_Insert);
 	d->menu_id_removeRecord = m_popupMenu->insertItem(
-		kapp->iconLoader()->loadIcon("button_cancel", KIcon::Small),
+		kapp->iconLoader()->loadIcon("button_cancel", TDEIcon::Small),
 		i18n("Remove Record"), this, TQT_SLOT(removeRecord()), TQt::CTRL+TQt::Key_Delete);
 #endif
 
@@ -322,7 +322,7 @@ void KexiTableView::clearVariables()
 	d->clearVariables();
 }
 
-/*void KexiTableView::initActions(KActionCollection *ac)
+/*void KexiTableView::initActions(TDEActionCollection *ac)
 {
 	emit reloadActions(ac);
 }*/
@@ -643,7 +643,7 @@ void KexiTableView::drawContents( TQPainter *p, int cx, int cy, int cw, int ch)
 		rowlast = tmp;
 	}
 
-// 	qDebug("cx:%3d cy:%3d w:%3d h:%3d col:%2d..%2d row:%2d..%2d tsize:%4d,%4d", 
+// 	tqDebug("cx:%3d cy:%3d w:%3d h:%3d col:%2d..%2d row:%2d..%2d tsize:%4d,%4d", 
 //	cx, cy, cw, ch, colfirst, collast, rowfirst, rowlast, tableSize().width(), tableSize().height());
 //	triggerUpdate();
 
@@ -923,7 +923,7 @@ TQPoint KexiTableView::viewportToContents2( const TQPoint& vp )
 
 void KexiTableView::paintEmptyArea( TQPainter *p, int cx, int cy, int cw, int ch )
 {
-//  qDebug("%s: paintEmptyArea(x:%d y:%d w:%d h:%d)", (const char*)parentWidget()->caption(),cx,cy,cw,ch);
+//  tqDebug("%s: paintEmptyArea(x:%d y:%d w:%d h:%d)", (const char*)parentWidget()->caption(),cx,cy,cw,ch);
 
 	// Regions work with shorts, so avoid an overflow and adjust the
 	// table size to the visible size
@@ -1224,11 +1224,11 @@ static bool overrideEditorShortcutNeeded(TQKeyEvent *e)
 bool KexiTableView::shortCutPressed( TQKeyEvent *e, const TQCString &action_name )
 {
 	const int k = e->key();
-	KAction *action = m_sharedActions[action_name];
+	TDEAction *action = m_sharedActions[action_name];
 	if (action) {
 		if (!action->isEnabled())//this action is disabled - don't process it!
 			return false; 
-		if (action->shortcut() == KShortcut( KKey(e) )) {
+		if (action->shortcut() == TDEShortcut( KKey(e) )) {
 			//special cases when we need to override editor's shortcut
 			if (overrideEditorShortcutNeeded(e)) {
 				return true;
@@ -2593,8 +2593,8 @@ KexiTableItem *KexiTableView::highlightedItem() const
 
 void KexiTableView::slotSettingsChanged(int category)
 {
-	if (category==KApplication::SETTINGS_SHORTCUTS) {
-		d->contextMenuKey = KGlobalSettings::contextMenuKey();
+	if (category==TDEApplication::SETTINGS_SHORTCUTS) {
+		d->contextMenuKey = TDEGlobalSettings::contextMenuKey();
 	}
 }
 
