@@ -34,12 +34,12 @@
 #include <tqwidgetstack.h>
 
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 #include <kpushbutton.h>
 
 #include "iconsidepane.h"
@@ -69,7 +69,7 @@ void EntryItem::reloadPixmap()
 {
   int size = (int)navigator()->viewMode();
   if ( size != 0 )
-    mPixmap = KGlobal::iconLoader()->loadIcon( mPixmapName, KIcon::Desktop, size );
+    mPixmap = TDEGlobal::iconLoader()->loadIcon( mPixmapName, TDEIcon::Desktop, size );
   else
     mPixmap = TQPixmap();
 }
@@ -203,10 +203,10 @@ void EntryItem::setPaintActive( bool paintActive )
 
 // ************************************************
 
-Navigator::Navigator(bool _selectable, KPopupMenu * menu, IconSidePane *_iconsidepane, TQWidget *parent, const char *name )
-  : KListBox( parent, name ), mSidePane( _iconsidepane ), mPopupMenu( menu )
+Navigator::Navigator(bool _selectable, TDEPopupMenu * menu, IconSidePane *_iconsidepane, TQWidget *parent, const char *name )
+  : TDEListBox( parent, name ), mSidePane( _iconsidepane ), mPopupMenu( menu )
 {
-  setSelectionMode( KListBox::Single );
+  setSelectionMode( TDEListBox::Single );
   viewport()->setBackgroundMode( PaletteBackground );
   setFrameStyle( TQFrame::NoFrame );
   setHScrollBarMode( TQScrollView::AlwaysOff );
@@ -246,7 +246,7 @@ bool Navigator::showIcons()
 
 void Navigator::mouseReleaseEvent(TQMouseEvent *e)
 {
-  KListBox::mouseReleaseEvent(e);
+  TDEListBox::mouseReleaseEvent(e);
   if ( e->button() != Qt::LeftButton || !mLeftMouseButtonPressed )
     return;
   if ( itemAt( e->pos() ) && executedItem == selectedItem() )
@@ -266,13 +266,13 @@ void Navigator::mousePressEvent(TQMouseEvent *e)
   }
   else
     mLeftMouseButtonPressed = true;
-  KListBox::mousePressEvent(e);
+  TDEListBox::mousePressEvent(e);
 }
 
 void Navigator::enterEvent( TQEvent *event )
 {
   // work around TQt behaviour: onItem is not emmitted in enterEvent()
-  KListBox::enterEvent( event );
+  TDEListBox::enterEvent( event );
   emit onItem( itemAt( mapFromGlobal( TQCursor::pos() ) ) );
 }
 
@@ -415,7 +415,7 @@ IconSidePane::IconSidePane(TQWidget *parent, const char *name )
   mShowIcons = KoShellSettings::sidePaneShowIcons();
   mShowText = KoShellSettings::sidePaneShowText();
   mViewMode = sizeIntToEnum( KoShellSettings::sidePaneIconSize() );
-  mPopupMenu = new KPopupMenu(0);
+  mPopupMenu = new TDEPopupMenu(0);
   mPopupMenu->insertTitle( i18n( "Icon Size" ) );
   mPopupMenu->insertItem( i18n( "Large" ), (int)LargeIcons );
   mPopupMenu->setItemEnabled( (int)LargeIcons, mShowIcons );
@@ -580,12 +580,12 @@ IconViewMode IconSidePane::sizeIntToEnum(int size) const
   }
 }
 
-void IconSidePane::setActionCollection( KActionCollection *actionCollection )
+void IconSidePane::setActionCollection( TDEActionCollection *actionCollection )
 {
   mActionCollection = actionCollection;
 }
 
-KActionCollection *IconSidePane::actionCollection() const
+TDEActionCollection *IconSidePane::actionCollection() const
 {
   return mActionCollection;
 }
