@@ -24,7 +24,7 @@
 #include "KPrTextObject.h"
 #include "KPrView.h"
 #include "KPrBackground.h"
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <dcopclient.h>
 #include "KPrDocument.h"
 #include "KPrCanvas.h"
