@@ -44,7 +44,7 @@
 #include <KoStore.h>
 #include <KoOasisStore.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 #include <tqxml.h>
@@ -88,7 +88,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return 0;
     }
     //kdDebug() << "KWPasteTextCommand::execute m_parag=" << m_parag << " m_idx=" << m_idx
@@ -155,7 +155,7 @@ KoTextCursor * KWPasteTextCommand::execute( KoTextCursor *c )
                 TQDomElement formatElem = layout.namedItem( "FORMAT" ).toElement();
                 if ( !formatElem.isNull() )
                 {
-                    KoTextFormat f = parag->loadFormat( formatElem, 0L, TQFont(), KGlobal::locale()->language(),false );
+                    KoTextFormat f = parag->loadFormat( formatElem, 0L, TQFont(), TDEGlobal::locale()->language(),false );
                     KoTextFormat * defaultFormat = doc->formatCollection()->format( &f );
                     // Last paragraph (i.e. only one in all) : some of the text might be from before the paste
                     int endIndex = (item == count-1) ? c->index() : parag->string()->length() - 1;
@@ -206,7 +206,7 @@ KoTextCursor * KWPasteTextCommand::unexecute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return 0;
     }
     cursor.setParag( firstParag );
@@ -215,7 +215,7 @@ KoTextCursor * KWPasteTextCommand::unexecute( KoTextCursor *c )
 
     KoTextParag *lastParag = doc->paragAt( m_lastParag );
     if ( !lastParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
         return 0;
     }
     Q_ASSERT( lastParag->document() );
@@ -255,7 +255,7 @@ KoTextCursor * KWOasisPasteCommand::execute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return c;
     }
     //kdDebug() << "KWOasisPasteCommand::execute m_parag=" << m_parag << " m_idx=" << m_idx
@@ -285,7 +285,7 @@ KoTextCursor * KWOasisPasteCommand::unexecute( KoTextCursor *c )
 {
     KoTextParag *firstParag = doc->paragAt( m_parag );
     if ( !firstParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_parag, doc->lastParag()->paragId() );
         return 0;
     }
     cursor.setParag( firstParag );
@@ -294,7 +294,7 @@ KoTextCursor * KWOasisPasteCommand::unexecute( KoTextCursor *c )
 
     KoTextParag *lastParag = doc->paragAt( m_lastParag );
     if ( !lastParag ) {
-        qWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", m_lastParag, doc->lastParag()->paragId() );
         return 0;
     }
     Q_ASSERT( lastParag->document() );
@@ -340,7 +340,7 @@ void KWTextDeleteCommand::createBookmarkList()
 #if 0
     KoTextParag *s = doc ? doc->paragAt( id ) : parag;
     if ( !s ) {
-        qWarning( "can't locate parag at %d, last parag: %d", id, doc->lastParag()->paragId() );
+        tqWarning( "can't locate parag at %d, last parag: %d", id, doc->lastParag()->paragId() );
         return;
     }
 
