@@ -27,7 +27,7 @@ namespace std { }
 using namespace std;
 #include <tqwmatrix.h>
 
-#include <kparts/part.h>
+#include <tdeparts/part.h>
 #include <kurl.h>
 #include <kservice.h>
 #include <KoGlobal.h>
@@ -61,7 +61,7 @@ class KoOpenPane;
 class KOFFICECORE_EXPORT KoDocument : public KParts::ReadWritePart
 {
     Q_OBJECT
-  TQ_OBJECT
+  
     TQ_PROPERTY( TQCString dcopObjectId READ dcopObjectId)
     TQ_PROPERTY( bool backupFile READ backupFile WRITE setBackupFile )
 
@@ -114,7 +114,7 @@ public:
     /**
      * Returns the action described action object. In fact only the "name" attribute
      * of @p element is of interest here. The method searches first in the
-     * KActionCollection of the first view and then in the KActionCollection of this
+     * TDEActionCollection of the first view and then in the TDEActionCollection of this
      * document.
      * This allows %KOffice applications to define actions in both the view and the document.
      * They should only define view-actions (like zooming and stuff) in the view.
@@ -126,7 +126,7 @@ public:
      * @see KXMLGUIClient::actionCollection
      * @see KoView::action
      */
-    virtual KAction *action( const TQDomElement &element ) const;
+    virtual TDEAction *action( const TQDomElement &element ) const;
 
     /**
      * Returns the DOM document which describes the GUI of the
@@ -181,33 +181,33 @@ public:
     /**
      * @brief Used by KoApplication, and by KoMainWindow, when no document exists yet.
      *
-     * With the help of @p instance or KApplication::instance() this
+     * With the help of @p instance or TDEApplication::instance() this
      * method figures out which .desktop file matches this application. In this
-     * file it searches for the "X-KDE-NativeMimeType" entry and returns it.
+     * file it searches for the "X-TDE-NativeMimeType" entry and returns it.
      *
      * @see KService
      * @see KDesktopFile
      */
-    static TQCString readNativeFormatMimeType( KInstance *instance = 0 );
+    static TQCString readNativeFormatMimeType( TDEInstance *instance = 0 );
 
     /**
      * Used by KoMainWindow, when no document exists yet.
      *
-     * With the help of @p instance or KApplication::instance() this
+     * With the help of @p instance or TDEApplication::instance() this
      * method figures out which .desktop file matches this application. In this
-     * file it searches for the "X-KDE-ExtraNativeMimeTypes" entry and returns it.
+     * file it searches for the "X-TDE-ExtraNativeMimeTypes" entry and returns it.
      *
      * @see KService
      * @see KDesktopFile
      */
-    static TQStringList readExtraNativeMimeTypes( KInstance *instance = 0 );
+    static TQStringList readExtraNativeMimeTypes( TDEInstance *instance = 0 );
 
     /**
-     * With the help of @p instance or KApplication::instance() this
+     * With the help of @p instance or TDEApplication::instance() this
      * method figures out which .desktop file matches this application,
      * and returns the KService instance for it.
      */
-    static KService::Ptr readNativeService( KInstance *instance = 0 );
+    static KService::Ptr readNativeService( TDEInstance *instance = 0 );
 
     /**
      * setup the XML reader, so that we don't have to duplicate the code.
@@ -218,14 +218,14 @@ public:
      * To be preferred when a document exists. It is fast when calling
      * it multiple times since it caches the result that readNativeFormatMimeType()
      * delivers.
-     * This comes from the X-KDE-NativeMimeType key in the .desktop file
+     * This comes from the X-TDE-NativeMimeType key in the .desktop file
      * You do NOT have to reimplement this (it is only virtual for kounavail).
      */
     virtual TQCString nativeFormatMimeType() const;
 
     /**
      * Returns the OASIS OpenDocument mimetype of the document, if supported
-     * This comes from the X-KDE-NativeOasisMimeType key in the .desktop file
+     * This comes from the X-TDE-NativeOasisMimeType key in the .desktop file
      */
     TQCString nativeOasisMimeType() const;
 
@@ -1123,18 +1123,18 @@ protected:
     /**
      * Creates the open widget showed at application start up.
      * @param parent the parent widget
-     * @param instance the KInstance to be used for KConfig data
+     * @param instance the TDEInstance to be used for TDEConfig data
      * @param templateType the template-type (group) that should be selected on creation.
      * @since 1.5
      */
-    KoOpenPane* createOpenPane( TQWidget* parent, KInstance* instance,
+    KoOpenPane* createOpenPane( TQWidget* parent, TDEInstance* instance,
                                 const TQString& templateType = TQString());
 
 private slots:
     void slotChildChanged( KoChild *c );
     void slotChildDestroyed();
     void slotAutoSave();
-    void slotStarted( KIO::Job* );
+    void slotStarted( TDEIO::Job* );
     void startCustomDocument();
     /**
      * Removes the open widget showed at application start up.
